@@ -198,6 +198,9 @@ def read_command_line(cmd_line):
         '--report',
         action="store_true",
         help='Force reporting, even if no new issues were found')
+    parser.add_argument('--report-tool',
+                        default=None,
+                        help='Name of tool to use for generating report')
     #build options
     parser.add_argument('--dir',
                         dest='intermediate_dir',
@@ -254,10 +257,16 @@ def build_under_coverity(intermediate_dir, command, strip_path):
     run_command("cov-build", "--dir", intermediate_dir, *command)
     # Analyze
     run_command("cov-analyze", "--dir", intermediate_dir, "--strip-path",
-                strip_path, "--enable-constraint-fpp", "--ticker-mode", "none",
-                "--disable-default", "--concurrency", "--security", "--rule",
-                "--enable-fnptr", "--enable-virtual", "--enable",
-                "SECURE_CODING")
+                strip_path, "--ticker-mode", "none", "--security",
+                "--concurrency", "--enable-constraint-fpp", "--enable-fnptr",
+                "--enable-virtual", "--disable", "ASSERT_SIDE_EFFECT",
+                "--disable", "AUTO_CAUSES_COPY", "--disable",
+                "BAD_CHECK_OF_WAIT_COND", "--disable", "BAD_SHIFT",
+                "--disable", "COPY_INSTEAD_OF_MOVE", "--disable",
+                "INEFFICIENT_RESERVE", "--disable", "MISSING_COMMA",
+                "--disable", "MISSING_MOVE_ASSIGNMENT", "--disable",
+                "OVERLAPPING_COPY", "--disable", "STREAM_FORMAT_STATE",
+                "--disable", "UNINTENDED_INTEGER_DIVISION")
 
 
 # pylint: disable=too-many-arguments,too-many-locals,too-many-positional-arguments
@@ -653,36 +662,14 @@ disa-stig:
 
     # Special environment with Coverity user information
     env = os.environ.copy()
-    if args.password:
-        env["COVERITY_PASSPHRASE"] = args.password
-    if args.user:
-        env["COV_USER"] = args.user
 
-    report_path = os.path.join(args.report_dir, "cvss_report.pdf")
-    arguments = [
-        "_covreport.yml",
-        "--output",
-        report_path,
-        "--report",
-    ]
-    if args.password:
-        arguments.extend([
-            "--password",
-            "env:COVERITY_PASSPHRASE",
-        ])
-    run_command("cov-generate-cvss-report", *arguments, env=env)
-    report_path = os.path.join(args.report_dir, "security_report.pdf")
-    arguments = [
-        "_covreport.yml",
-        "--output",
-        report_path,
-    ]
-    if args.password:
-        arguments.extend([
-            "--password",
-            "env:COVERITY_PASSPHRASE",
-        ])
-    run_command("cov-generate-security-report", *arguments, env=env)
+    if args.report_tool:
+        report_path = os.path.join(args.report_dir, "cov_report.html")
+        arguments = [
+            "_covreport.yml", "--output", report_path, "--auth-key-file",
+            args.auth_key_file
+        ]
+        run_command(args.report_tool, *arguments, env=env)
 
 
 def run(args):
@@ -722,21 +709,20 @@ def run(args):
         error_count = summary.problems
         xunit_from_report(os.path.join(args.report_dir, "xunit.xml"), summary)
     snapshot_id = None
-    if args.report or error_count > 0:
-        publish_to_coverity_connect(args.intermediate_dir,
-                                    args.url,
-                                    args.stream,
-                                    args.code_version,
-                                    args.strip_path,
-                                    args.description,
-                                    "_snapshot_id.txt",
-                                    user=args.user,
-                                    password=args.password,
-                                    auth_key_file=args.auth_key_file)
 
-        with open("_snapshot_id.txt", "r",
-                  encoding="utf8") as snapshot_id_file:
-            snapshot_id = snapshot_id_file.read().strip()
+    publish_to_coverity_connect(args.intermediate_dir,
+                                args.url,
+                                args.stream,
+                                args.code_version,
+                                args.strip_path,
+                                args.description,
+                                "_snapshot_id.txt",
+                                user=args.user,
+                                password=args.password,
+                                auth_key_file=args.auth_key_file)
+
+    with open("_snapshot_id.txt", "r", encoding="utf8") as snapshot_id_file:
+        snapshot_id = snapshot_id_file.read().strip()
     snapshot_info = {}
     if snapshot_id is not None:
         snapshot_info["id"] = snapshot_id
@@ -747,7 +733,7 @@ def run(args):
               encoding="utf8") as info_file:
         json.dump(snapshot_info, info_file, indent=2)
 
-    if snapshot_id is not None:
+    if args.report and snapshot_id is not None:
         write_reports(args, snapshot_id)
     return error_count
 
